// Copyright (C) 2006, 2007, 2008, 2009 by Florent Lamiraux, Thomas
// Moulard, Mathieu Poirier, CNRS.
//
// This file is part of the hppWalkPlanner.
//
// hppWalkPlanner is free software: you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation, either version 3 of
// the License, or (at your option) any later version.
//
// hppWalkPlanner is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with hppWalkPlanner. If not, see
// <http://www.gnu.org/licenses/>.

#ifndef HPPWALKPLANNER_TESTDIRECTPATH_HH
# define HPPWALKPLANNER_TESTDIRECTPATH_HH

#include <KineoWorks2/kwsDPLinear.h>
#include <KineoModel/kppDeviceComponent.h>

class TestDirectPath
{
public:
  /// \brief Initialization of the object: create a device and a
  /// steering method.
  ktStatus init ();

  /// \brief Get pointer to device.
  CkppDeviceComponentShPtr device ()
  {
    return attDevice;
  }

  /// \brief Get pointer to steering method.
  CkwsSteeringMethodShPtr
  steeringMethod ()
  {
    return attSteeringMethod;
  }

private:
  /**
     \brief create a device

     Device is stored in parent class CtestKwsDirectPath.
  */
  ktStatus createDevice ();

  /**
     \brief Create a FLatORiENTedINtErpolation steering method.

     Steering method is stored in parent class CtestKwsDirectPath.
  */
  ktStatus createSteeringMethod ();

  /// \brief Device used to randomly generate configurations.
  CkppDeviceComponentShPtr attDevice;

  /// \brief Steering method to test.
  CkwsSteeringMethodShPtr attSteeringMethod;

};

#endif //! HPPWALKPLANNER_TESTDIRECTPATH_HH
